@@ -86,7 +86,9 @@ class StateUpdater:
                     remote_value.device_name,
                     remote_value.feature_name,
                 )
-                await remote_value.read_state(wait_for_result=True)
+                # shield from cancellation so update_received() don't cancel the
+                # ValueReader leaving the telegram_received_cb until next telegram
+                await asyncio.shield(remote_value.read_state(wait_for_result=True))
 
         tracker_type, update_interval = parse_tracker_options(tracker_options)
         tracker = _StateTracker(
@@ -156,16 +158,18 @@ class _StateTracker:
 
     def start(self):
         """Start StateTracker - read state on call."""
+        self.stop()
         self._task = asyncio.create_task(self._start_init())
 
     async def _start_init(self):
         """Initialize state, start update loop if appropriate."""
         await self._read_state()
         if self.tracker_type is not StateTrackerType.INIT:
-            self._start_waiting()
+            self.reset()
 
-    def _start_waiting(self):
-        """Start StateTracker - wait for value to expire."""
+    def reset(self):
+        """Start / Restart StateTracker timer - wait for value to expire."""
+        self.stop()
         self._task = asyncio.create_task(self._update_loop())
 
     def stop(self):
@@ -174,11 +178,6 @@ class _StateTracker:
             self._task.cancel()
             self._task = None
 
-    def reset(self):
-        """Restart the timer."""
-        self.stop()
-        self._start_waiting()
-
     def update_received(self):
         """Reset the timer if a telegram was received for a "expire" typed StateUpdater."""
         if self.tracker_type == StateTrackerType.EXPIRE:
