@@ -20,7 +20,7 @@ class ValueReader:
 
     # pylint: disable=too-many-instance-attributes
 
-    def __init__(self, xknx, group_address, timeout_in_seconds=1):
+    def __init__(self, xknx, group_address, timeout_in_seconds=2):
         """Initialize ValueReader class."""
         self.xknx = xknx
         self.group_address = group_address
@@ -53,17 +53,13 @@ class ValueReader:
 
     async def telegram_received(self, telegram):
         """Test if telegram has correct group address and trigger event."""
-        if telegram.telegramtype not in (
+        if telegram.group_address == self.group_address and telegram.telegramtype in (
             TelegramType.GROUP_RESPONSE,
             TelegramType.GROUP_WRITE,
         ):
-            return False
-        if self.group_address != telegram.group_address:
-            return False
-        self.success = True
-        self.received_telegram = telegram
-        self.response_received_or_timeout.set()
-        return True
+            self.success = True
+            self.received_telegram = telegram
+            self.response_received_or_timeout.set()
 
     def timeout(self):
         """Handle timeout for not having received expected group response."""
