@@ -25,10 +25,11 @@ class BinarySensor(Device):
     def __init__(
         self,
         xknx,
-        name,
+        name: str,
         group_address_state=None,
+        invert: Optional[bool] = False,
         sync_state: bool = True,
-        ignore_internal_state: bool = True,
+        ignore_internal_state: bool = False,
         device_class: str = None,
         reset_after: Optional[float] = None,
         actions: List[Action] = None,
@@ -43,7 +44,7 @@ class BinarySensor(Device):
 
         self.actions = actions
         self.device_class = device_class
-        self.ignore_internal_state = ignore_internal_state
+        self.ignore_internal_state = ignore_internal_state or bool(context_timeout)
         self.reset_after = reset_after
         self.state = None
 
@@ -57,6 +58,7 @@ class BinarySensor(Device):
         self.remote_value = RemoteValueSwitch(
             xknx,
             group_address_state=group_address_state,
+            invert=invert,
             sync_state=sync_state,
             device_name=self.name,
             # after_update called internally
@@ -79,11 +81,12 @@ class BinarySensor(Device):
     def from_config(cls, xknx, name, config):
         """Initialize object from configuration structure."""
         group_address_state = config.get("group_address_state")
+        invert = config.get("invert")
         context_timeout = config.get("context_timeout")
         reset_after = config.get("reset_after")
         sync_state = config.get("sync_state", True)
         device_class = config.get("device_class")
-        ignore_internal_state = config.get("ignore_internal_state", True)
+        ignore_internal_state = config.get("ignore_internal_state", False)
         actions = []
         if "actions" in config:
             for action in config["actions"]:
@@ -94,6 +97,7 @@ class BinarySensor(Device):
             xknx,
             name,
             group_address_state=group_address_state,
+            invert=invert,
             sync_state=sync_state,
             ignore_internal_state=ignore_internal_state,
             context_timeout=context_timeout,
@@ -175,13 +179,19 @@ class BinarySensor(Device):
     async def process_group_write(self, telegram):
         """Process incoming and outgoing GROUP WRITE telegram."""
         if await self.remote_value.process(telegram, always_callback=True):
+            self._process_reset_after()
 
-            if self.reset_after is not None and self.state:
-                if self._reset_task:
-                    self._reset_task.cancel()
-                self._reset_task = asyncio.create_task(
-                    self._reset_state(self.reset_after)
-                )
+    async def process_group_response(self, telegram):
+        """Process incoming GroupValueResponse telegrams."""
+        if await self.remote_value.process(telegram, always_callback=False):
+            self._process_reset_after()
+
+    def _process_reset_after(self):
+        """Create Task for resetting state if 'reset_after' is configured."""
+        if self.reset_after is not None and self.state:
+            if self._reset_task:
+                self._reset_task.cancel()
+            self._reset_task = asyncio.create_task(self._reset_state(self.reset_after))
 
     async def _reset_state(self, wait_seconds: float):
         await asyncio.sleep(wait_seconds)
