@@ -68,7 +68,8 @@ class DateTime(Device):
                 await asyncio.sleep(minutes * 60)
 
         if self.localtime:
-            return self.xknx.loop.create_task(broadcast_loop(self, minutes=minutes))
+            loop = asyncio.get_event_loop()
+            return loop.create_task(broadcast_loop(self, minutes=minutes))
         return None
 
     async def broadcast_localtime(self, response=False):
@@ -84,7 +85,7 @@ class DateTime(Device):
         if self.localtime:
             await self.broadcast_localtime(True)
         else:
-            await self._remote_value.send(response=True)
+            await self._remote_value.respond()
 
     async def sync(self, wait_for_result=False):
         """Read state of device from KNX bus. Used here to broadcast time to KNX bus."""
