@@ -1,8 +1,12 @@
 """Module for managing a notification via KNX."""
+import logging
+
 from xknx.remote_value import RemoteValueString
 
 from .device import Device
 
+logger = logging.getLogger("xknx.log")
+
 
 class Notification(Device):
     """Class for managing a notification."""
@@ -56,7 +60,7 @@ class Notification(Device):
         await self._message.set(cropped_message)
 
     async def process_group_write(self, telegram):
-        """Process incoming GROUP WRITE telegram."""
+        """Process incoming and outgoing GROUP WRITE telegram."""
         await self._message.process(telegram)
 
     async def do(self, action):
@@ -64,7 +68,7 @@ class Notification(Device):
         if action.startswith("message:"):
             await self.set(action[8:])
         else:
-            self.xknx.logger.warning(
+            logger.warning(
                 "Could not understand action %s for device %s", action, self.get_name()
             )
 
