@@ -1,5 +1,5 @@
 """Abstraction to send ConnectonStateRequest and wait for ConnectionStateResponse."""
-from xknx.knxip import HPAI, ConnectionStateResponse, KNXIPFrame, KNXIPServiceType
+from xknx.knxip import HPAI, ConnectionStateRequest, ConnectionStateResponse, KNXIPFrame
 
 from .request_response import RequestResponse
 
@@ -13,12 +13,12 @@ class ConnectionState(RequestResponse):
         super().__init__(xknx, self.udp_client, ConnectionStateResponse)
         self.communication_channel_id = communication_channel_id
 
-    def create_knxipframe(self):
+    def create_knxipframe(self) -> KNXIPFrame:
         """Create KNX/IP Frame object to be sent to device."""
         (local_addr, local_port) = self.udpclient.getsockname()
-        knxipframe = KNXIPFrame(self.xknx)
-        knxipframe.init(KNXIPServiceType.CONNECTIONSTATE_REQUEST)
-        knxipframe.body.communication_channel_id = self.communication_channel_id
-        knxipframe.body.control_endpoint = HPAI(ip_addr=local_addr, port=local_port)
-
-        return knxipframe
+        connectionstate_request = ConnectionStateRequest(
+            self.xknx,
+            communication_channel_id=self.communication_channel_id,
+            control_endpoint=HPAI(ip_addr=local_addr, port=local_port),
+        )
+        return KNXIPFrame.init_from_body(connectionstate_request)
