@@ -7,6 +7,7 @@ GatewayScanner is an abstraction for searching for KNX/IP devices on the local n
 """
 
 import asyncio
+import logging
 from typing import List, Optional
 
 import netifaces
@@ -16,11 +17,14 @@ from xknx.knxip import (
     DIBSuppSVCFamilies,
     KNXIPFrame,
     KNXIPServiceType,
+    SearchRequest,
     SearchResponse,
 )
 
 from .udp_client import UDPClient
 
+logger = logging.getLogger("xknx.log")
+
 
 class GatewayDescriptor:
     """Used to return information about the discovered gateways."""
@@ -138,14 +142,12 @@ class GatewayScanner:
                 ip_addr = af_inet[0]["addr"]
                 await self._search_interface(interface, ip_addr)
             except KeyError:
-                self.xknx.logger.info(
-                    "Could not connect to an KNX/IP device on %s", interface
-                )
+                logger.info("Could not connect to an KNX/IP device on %s", interface)
                 continue
 
     async def _search_interface(self, interface, ip_addr):
         """Send a search request on a specific interface."""
-        self.xknx.logger.debug("Searching on %s / %s", interface, ip_addr)
+        logger.debug("Searching on %s / %s", interface, ip_addr)
 
         udp_client = UDPClient(
             self.xknx,
@@ -162,18 +164,17 @@ class GatewayScanner:
         self._udp_clients.append(udp_client)
 
         (local_addr, local_port) = udp_client.getsockname()
-        knx_ip_frame = KNXIPFrame(self.xknx)
-        knx_ip_frame.init(KNXIPServiceType.SEARCH_REQUEST)
-        knx_ip_frame.body.discovery_endpoint = HPAI(ip_addr=local_addr, port=local_port)
-        knx_ip_frame.normalize()
-        udp_client.send(knx_ip_frame)
+        search_request = SearchRequest(
+            self.xknx, discovery_endpoint=HPAI(ip_addr=local_addr, port=local_port)
+        )
+        udp_client.send(KNXIPFrame.init_from_body(search_request))
 
     def _response_rec_callback(
         self, knx_ip_frame: KNXIPFrame, udp_client: UDPClient
     ) -> None:
         """Verify and handle knxipframe. Callback from internal udpclient."""
         if not isinstance(knx_ip_frame.body, SearchResponse):
-            self.xknx.logger.warning("Could not understand knxipframe")
+            logger.warning("Could not understand knxipframe")
             return
 
         gateway = GatewayDescriptor(
@@ -204,9 +205,8 @@ class GatewayScanner:
 
     async def _start_timeout(self):
         """Start time out."""
-        self._timeout_handle = self.xknx.loop.call_later(
-            self.timeout_in_seconds, self._timeout
-        )
+        loop = asyncio.get_running_loop()
+        self._timeout_handle = loop.call_later(self.timeout_in_seconds, self._timeout)
 
     async def _stop_timeout(self):
         """Stop/cancel timeout."""
