@@ -3,11 +3,22 @@ Abstraction for handling KNX/IP routing.
 
 Routing uses UDP Multicast to broadcast and receive KNX/IP messages.
 """
-from xknx.knxip import APCICommand, KNXIPFrame, KNXIPServiceType
+import logging
+
+from xknx.knxip import (
+    APCICommand,
+    CEMIFrame,
+    CEMIMessageCode,
+    KNXIPFrame,
+    KNXIPServiceType,
+    RoutingIndication,
+)
 from xknx.telegram import TelegramDirection
 
 from .udp_client import UDPClient
 
+logger = logging.getLogger("xknx.log")
+
 
 class Routing:
     """Class for handling KNX/IP routing."""
@@ -32,18 +43,18 @@ class Routing:
     def response_rec_callback(self, knxipframe, _):
         """Verify and handle knxipframe. Callback from internal udpclient."""
         if knxipframe.header.service_type_ident != KNXIPServiceType.ROUTING_INDICATION:
-            self.xknx.logger.warning("Service type not implemented: %s", knxipframe)
+            logger.warning("Service type not implemented: %s", knxipframe)
         elif knxipframe.body.cemi is None:
             # ignore unsupported CEMI frame
             return
         elif knxipframe.body.cemi.src_addr == self.xknx.own_address:
-            self.xknx.logger.debug("Ignoring own packet")
+            logger.debug("Ignoring own packet")
         elif knxipframe.body.cemi.cmd not in (
             APCICommand.GROUP_READ,
             APCICommand.GROUP_WRITE,
             APCICommand.GROUP_RESPONSE,
         ):
-            self.xknx.logger.warning("APCI not implemented: %s", knxipframe)
+            logger.warning("APCI not implemented: %s", knxipframe)
         else:
             telegram = knxipframe.body.cemi.telegram
             telegram.direction = TelegramDirection.INCOMING
@@ -53,13 +64,14 @@ class Routing:
 
     async def send_telegram(self, telegram):
         """Send Telegram to routing connected device."""
-        knxipframe = KNXIPFrame(self.xknx)
-        knxipframe.init(KNXIPServiceType.ROUTING_INDICATION)
-        knxipframe.body.cemi.src_addr = self.xknx.own_address
-        knxipframe.body.cemi.telegram = telegram
-        knxipframe.body.cemi.sender = self.xknx.own_address
-        knxipframe.normalize()
-        await self.send_knxipframe(knxipframe)
+        cemi = CEMIFrame.init_from_telegram(
+            self.xknx,
+            telegram=telegram,
+            code=CEMIMessageCode.L_DATA_IND,
+            src_addr=self.xknx.own_address,
+        )
+        routing_indication = RoutingIndication(self.xknx, cemi=cemi)
+        await self.send_knxipframe(KNXIPFrame.init_from_body(routing_indication))
 
     async def send_knxipframe(self, knxipframe):
         """Send KNXIPFrame to connected routing device."""
