@@ -1,4 +1,7 @@
 """Basis class for all KNX/IP bodies."""
+import logging
+
+logger = logging.getLogger("xknx.log")
 
 
 class KNXIPBody:
@@ -10,22 +13,18 @@ class KNXIPBody:
 
     def calculated_length(self):
         """Get length of KNX/IP body."""
-        self.xknx.logger.warning(
+        logger.warning(
             "'calculated_length()' not implemented for %s", self.__class__.__name__
         )
 
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
         # pylint: disable=unused-argument
-        self.xknx.logger.warning(
-            "'from_knx()' not implemented for %s", self.__class__.__name__
-        )
+        logger.warning("'from_knx()' not implemented for %s", self.__class__.__name__)
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
-        self.xknx.logger.warning(
-            "'to_knx()' not implemented for %s", self.__class__.__name__
-        )
+        logger.warning("'to_knx()' not implemented for %s", self.__class__.__name__)
 
     def __eq__(self, other):
         """Equal operator."""
