@@ -6,13 +6,13 @@ A HPAI contains an IP address and a port.
 from xknx.exceptions import ConversionError, CouldNotParseKNXIP
 
 
-class HPAI():
+class HPAI:
     """Class for Module for Serialization and Deserialization."""
 
     LENGTH = 0x08
     TYPE_UDP = 0x01
 
-    def __init__(self, ip_addr='0.0.0.0', port=0):
+    def __init__(self, ip_addr="0.0.0.0", port=0):
         """Initialize HPAI object."""
         self.ip_addr = ip_addr
         self.port = port
@@ -25,19 +25,20 @@ class HPAI():
             raise CouldNotParseKNXIP("wrong HPAI length")
         if raw[1] != HPAI.TYPE_UDP:
             raise CouldNotParseKNXIP("wrong HPAI type")
-        self.ip_addr = "{0}.{1}.{2}.{3}".format(
-            raw[2], raw[3], raw[4], raw[5])
+        self.ip_addr = "{}.{}.{}.{}".format(raw[2], raw[3], raw[4], raw[5])
         self.port = raw[6] * 256 + raw[7]
         return HPAI.LENGTH
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
+
         def ip_addr_to_bytes(ip_addr):
             """Serialize ip address to byte array."""
             if not isinstance(ip_addr, str):
                 raise ConversionError("ip_addr is not a string")
             for i in ip_addr.split("."):
                 yield int(i)
+
         data = []
         data.append(HPAI.LENGTH)
         data.append(HPAI.TYPE_UDP)
@@ -48,7 +49,7 @@ class HPAI():
 
     def __str__(self):
         """Return object as readable string."""
-        return '<HPAI {0}:{1} />'.format(self.ip_addr, self.port)
+        return f"<HPAI {self.ip_addr}:{self.port} />"
 
     def __eq__(self, other):
         """Equal operator."""
