@@ -4,6 +4,8 @@ Module for managing a remote value typically used within a sensor.
 The module maps a given value_type to a DPT class and uses this class
 for serialization and deserialization of the KNX value.
 """
+from typing import List
+
 from xknx.dpt import DPTArray, DPTBase
 from xknx.exceptions import ConversionError
 
@@ -23,6 +25,7 @@ class RemoteValueSensor(RemoteValue):
         device_name=None,
         feature_name="Value",
         after_update_cb=None,
+        passive_group_addresses: List[str] = None,
     ):
         """Initialize RemoteValueSensor class."""
         # pylint: disable=too-many-arguments
@@ -40,6 +43,7 @@ class RemoteValueSensor(RemoteValue):
             device_name=device_name,
             feature_name=feature_name,
             after_update_cb=after_update_cb,
+            passive_group_addresses=passive_group_addresses,
         )
 
     def payload_valid(self, payload):
